# Control panels for Plone 5 have been moved to CMFPlone. We keep those imports
# for backwards compatibility.
from Products.CMFPlone.interfaces import IMailSchema  # noqa
from Products.CMFPlone.controlpanel.markup import MarkupControlPanel  # noqa
from Products.CMFPlone.controlpanel.bbb.markup import MarkupControlPanelAdapter  # noqa
